# plain-esbuild changelog

## [0.6.0](https://github.com/dropseed/plain/releases/plain-esbuild@0.6.0) (2025-09-19)

### What's changed

- Python 3.13 is now the minimum required version ([d86e307](https://github.com/dropseed/plain/commit/d86e307efb0d5e8f5001efccede4d58d0e26bfea))
- Package description has been added to the pyproject.toml ([4ebecd1](https://github.com/dropseed/plain/commit/4ebecd1856f96afc09a2ad6887224ae94b1a7395))
- README has been updated with proper formatting and installation instructions ([4ebecd1](https://github.com/dropseed/plain/commit/4ebecd1856f96afc09a2ad6887224ae94b1a7395))

### Upgrade instructions

- Upgrade your Python environment to Python 3.13 or newer

## [0.5.1](https://github.com/dropseed/plain/releases/plain-esbuild@0.5.1) (2025-06-24)

### What's changed

- Added this CHANGELOG file to the package so future releases include detailed notes ([82710c3](https://github.com/dropseed/plain/commit/82710c3c8300))

### Upgrade instructions

- No changes required
